==> chamilo-1.11.26.zip: chamilo-1.11.26/plugin/vchamilo/lang/english.php <==
<?php
/**
 * @copyright (c) 2014 Valery Fremaux
 * @license GNU General Public License - http://www.gnu.org/copyleft/gpl.html
 * @author Valery Fremaux <valery.fremaux@gmail.com>
 */
$strings['archiverealroot'] = 'Archive container real root (no symlinks here)';
$strings['backtoindex'] = 'Back to instance index';
$strings['badconnection'] = 'Connection FAILED';
$strings['cancel'] = 'Cancel';
$strings['choose'] = 'choose...';
$strings['clearcache'] = 'Clear Twig cache';
$strings['clearmastercache'] = 'Clear Twig cache for master';
$strings['closewindow'] = 'Close this window';
$strings['connectionok'] = 'Connection OK';
$strings['continue'] = 'Continue';
$strings['coursefolder'] = 'Physical dir';
$strings['courserealroot'] = 'Course container real root (no symlinks here)';
$strings['datalocation'] = 'Data location';
$strings['datapathavailable'] = 'Data path is available and ready to be used as : <br/>';
$strings['datapathnotavailable'] = 'Data path exists but has already files in it at <br/>';
$strings['datapathcreated'] = 'Data path has been created as :<br/>';
$strings['dbgroup'] = 'Database Settings';
$strings['dbhost'] = 'Database Host';
$strings['dbpassword'] = 'Password';
$strings['dbprefix'] = 'Database prefix';
$strings['dbuser'] = 'Username';
$strings['deleteifempty'] = 'Delete if empty';
$strings['deleteinstances'] = 'Remove instance';
$strings['destroyinstances'] = 'Full delete instance';
$strings['distributevalue'] = 'Distribute configuration value';
$strings['edit'] = 'Edit instance info';
$strings['emptysite'] = 'New empty site';
$strings['enable_virtualisation'] = 'Enable';
$strings['enabled'] = 'enabled';
$strings['enableinstances'] = 'Enable';
$strings['enabling'] = 'General enabling';
$strings['errormuststartwithcourses'] = 'the course folder MUST start with \'courses_\' to avoid directory conflicts';
$strings['homerealroot'] = 'Home container real root (no symlinks here)';
$strings['hostdefinition'] = 'Host definition';
$strings['hostlist'] = 'Other hosts';
$strings['institution'] = 'Institution';
$strings['lastcron'] = 'Last cron';
$strings['maindatabase'] = 'Database name';
$strings['manage_instances'] = 'Go to instance manager';
$strings['newinstance'] = 'Add new instance';
$strings['no'] = 'No';
$strings['plugin_comment'] = 'Allows the virtualization of Chamilo. Use your main Chamilo installation as a hub, then create instances based on the same code but with different databases, and generate snapshots, and manage all instances like VM images.';
$strings['plugin_title'] = 'Virtual Chamilo';
$strings['proxysettings'] = 'Proxy settings';
$strings['registerinstance'] = 'Register an instance';
$strings['rootweb'] = 'Web root';
$strings['savechanges'] = 'Save changes';
$strings['selectall'] = 'Select all';
$strings['selectnone'] = 'Deselect all';
$strings['sendconfigvalue'] = 'Distribute a configuration value';
$strings['setconfigvalue'] = 'Set a configuration value';
$strings['singledatabase'] = 'Single database';
$strings['sitename'] = 'Site Name';
$strings['snapshotinstance'] = 'Snapshot';
$strings['snapshotmaster'] = 'Snapshot master Chamilo';
$strings['statisticsdatabase'] = 'Statistics database';
$strings['successfinishedcapture'] = 'Snapshot of chamilo is finished';
$strings['sync_settings'] = 'Synchronize settings';
$strings['tableprefix'] = 'Table prefix';
$strings['template'] = 'Template';
$strings['templating'] = 'Templating';
$strings['testconnection'] = 'Test database connexion';
$strings['testdatapath'] = 'Test data location';
$strings['userpersonaldatabase'] = 'User personal database';
$strings['vchamilo'] = 'Virtual Chamilo';
$strings['vchamilosnapshot1'] = 'STEP 1 OF 3 : Directories for snapshot have been created. Continue with database backup ...';
$strings['vchamilosnapshot2'] = 'STEP 2 OF 3 : Databases have been backed up. Continue with saving files... beware this step can be long if a lot of content resides in the instance...';
$strings['vchamilosnapshot3'] = 'STEP 3 OF 3 : Files saved.';
$strings['withselection'] = 'With selection: ';
$strings['yes'] = 'Yes';

$strings['mysqlcmds'] = 'Mysql commands location';
$strings['mysqlcmd'] = 'Full path to mysql client command';
$strings['mysqldumpcms'] = 'Full path to mysqldump command';

$strings['sitenameinputerror'] = "Site Name is empty or invalid";
$strings['institutioninputerror'] = "Institution is empty or invalid";
$strings['rootwebinputerror'] = "Root web is empty or invalid";
$strings['databaseinputerror'] = "Database empty";
$strings['coursefolderinputerror'] = "Data location is empty";

$strings['httpproxyhost'] = "HTTP proxy host";
$strings['httpproxyport'] = "HTTP proxy port";
$strings['httpproxybypass'] = "HTTP proxy URL bypass";
$strings['httpproxyuser'] = "HTTP proxy user";
$strings['httpproxypassword'] = "HTTP proxy password";

$strings['variable'] = 'Variable';
$strings['subkey'] = 'Subkey';
$strings['category'] = 'Category';
$strings['accessurl'] = 'Access URL';
$strings['value'] = 'Value';
$strings['syncall'] = 'Sync all the selection';
$strings['syncthis'] = 'Sync this setting';

$strings['SiteNameExample'] = 'Example: Chamilo';
$strings['InstitutionExample'] = 'Example: Chamilo Association';
$strings['RootWebExample'] = 'Example: http://www.chamilo.org/ (with final slash)';
$strings['DatabaseDescription'] = 'A new database will be created with that name.';
$strings['RootWebExists'] = 'An instance with the same root web exists.';
$strings['ImportInstance'] = 'Import instance';
$strings['ConfigurationPath'] = 'Chamilo configuration path';
$strings['UploadRealRoot'] = 'Upload files';
$strings['DatabaseAccessShouldBeDifferentThanMasterChamilo'] = 'Database server should be different than the Chamilo master';
$strings['UrlAppendExample'] = 'Example: /chamilo_v1 (with first slash)';

$strings['FromVersion'] = 'From version';
$strings['CoursePath'] = 'Path to courses directory';
$strings['HomePath'] = 'Path to home directory';
$strings['UploadPath'] = 'Path to upload directory';

$strings['ArchiveUrl'] = 'Archive URL';
$strings['HomeUrl'] = 'Home URL';
$strings['UploadUrl'] = 'Upload URL';
$strings['CourseUrl'] = 'Course URL';
$strings['ThemeFolder'] = 'Theme folder';
$strings['ThemeFolderExplanation'] = 'Theme folder should be located inside the web/css/themes/ folder';

==> chamilo-1.11.32.zip: chamilo-1.11.32/plugin/vchamilo/lang/english.php <==
<?php
/**
 * @copyright (c) 2014 Valery Fremaux
 * @license GNU General Public License - http://www.gnu.org/copyleft/gpl.html
 * @author Valery Fremaux <valery.fremaux@gmail.com>
 */
$strings['archiverealroot'] = 'Cache container real root (system path, no symlinks here)';
$strings['backtoindex'] = 'Back to instance index';
$strings['badconnection'] = 'Connection FAILED';
$strings['cancel'] = 'Cancel';
$strings['choose'] = 'choose...';
$strings['clearcache'] = 'Clear Twig cache';
$strings['clearmastercache'] = 'Clear Twig cache for master';
$strings['closewindow'] = 'Close this window';
$strings['connectionok'] = 'Connection OK';
$strings['continue'] = 'Continue';
$strings['coursefolder'] = 'Physical dir';
$strings['courserealroot'] = 'Course container real root (no symlinks here)';
$strings['datalocation'] = 'Data location';
$strings['datapathavailable'] = 'Data path is available and ready to be used as : <br/>';
$strings['datapathnotavailable'] = 'Data path exists but has already files in it at <br/>';
$strings['datapathcreated'] = 'Data path has been created as :<br/>';
$strings['dbgroup'] = 'Database Settings';
$strings['dbhost'] = 'Database Host';
$strings['dbpassword'] = 'Password';
$strings['dbprefix'] = 'Database prefix';
$strings['dbuser'] = 'Username';
$strings['deleteifempty'] = 'Delete if empty';
$strings['deleteinstances'] = 'Remove instance';
$strings['destroyinstances'] = 'Full delete instance';
$strings['distributevalue'] = 'Distribute configuration value';
$strings['edit'] = 'Edit instance info';
$strings['emptysite'] = 'New empty site';
$strings['enable_virtualisation'] = 'Enable';
$strings['enabled'] = 'enabled';
$strings['enableinstances'] = 'Enable';
$strings['enabling'] = 'General enabling';
$strings['errormuststartwithcourses'] = 'the course folder MUST start with \'courses_\' to avoid directory conflicts';
$strings['homerealroot'] = 'Home container real root (no symlinks here)';
$strings['hostdefinition'] = 'Host definition';
$strings['hostlist'] = 'Other hosts';
$strings['institution'] = 'Institution';
$strings['lastcron'] = 'Last cron';
$strings['maindatabase'] = 'Database name';
$strings['manage_instances'] = 'Go to instance manager';
$strings['newinstance'] = 'Add new instance';
$strings['no'] = 'No';
$strings['plugin_comment'] = 'Allows the virtualization of Chamilo. Use your main Chamilo installation as a hub, then create instances based on the same code but with different databases, and generate snapshots, and manage all instances like VM images.';
$strings['plugin_title'] = 'Virtual Chamilo';
$strings['proxysettings'] = 'Proxy settings';
$strings['registerinstance'] = 'Register an instance';
$strings['rootweb'] = 'Web root';
$strings['savechanges'] = 'Save changes';
$strings['selectall'] = 'Select all';
$strings['selectnone'] = 'Deselect all';
$strings['sendconfigvalue'] = 'Distribute a configuration value';
$strings['setconfigvalue'] = 'Set a configuration value';
$strings['singledatabase'] = 'Single database';
$strings['sitename'] = 'Site Name';
$strings['snapshotinstance'] = 'Snapshot';
$strings['snapshotmaster'] = 'Snapshot master Chamilo';
$strings['statisticsdatabase'] = 'Statistics database';
$strings['successfinishedcapture'] = 'Snapshot of chamilo is finished';
$strings['sync_settings'] = 'Synchronize settings';
$strings['tableprefix'] = 'Table prefix';
$strings['template'] = 'Template';
$strings['templating'] = 'Templating';
$strings['testconnection'] = 'Test database connexion';
$strings['testdatapath'] = 'Test data location';
$strings['userpersonaldatabase'] = 'User personal database';
$strings['vchamilo'] = 'Virtual Chamilo';
$strings['vchamilosnapshot1'] = 'STEP 1 OF 3 : Directories for snapshot have been created. Continue with database backup ...';
$strings['vchamilosnapshot2'] = 'STEP 2 OF 3 : Databases have been backed up. Continue with saving files... beware this step can be long if a lot of content resides in the instance...';
$strings['vchamilosnapshot3'] = 'STEP 3 OF 3 : Files saved.';
$strings['withselection'] = 'With selection: ';
$strings['yes'] = 'Yes';

$strings['mysqlcmds'] = 'Mysql commands location';
$strings['mysqlcmd'] = 'Full path to mysql client command';
$strings['mysqldumpcms'] = 'Full path to mysqldump command';

$strings['sitenameinputerror'] = "Site Name is empty or invalid";
$strings['institutioninputerror'] = "Institution is empty or invalid";
$strings['rootwebinputerror'] = "Root web is empty or invalid";
$strings['databaseinputerror'] = "Database empty";
$strings['coursefolderinputerror'] = "Data location is empty";

$strings['httpproxyhost'] = "HTTP proxy host";
$strings['httpproxyport'] = "HTTP proxy port";
$strings['httpproxybypass'] = "HTTP proxy URL bypass";
$strings['httpproxyuser'] = "HTTP proxy user";
$strings['httpproxypassword'] = "HTTP proxy password";

$strings['variable'] = 'Variable';
$strings['subkey'] = 'Subkey';
$strings['category'] = 'Category';
$strings['accessurl'] = 'Access URL';
$strings['value'] = 'Value';
$strings['syncall'] = 'Sync all the selection';
$strings['syncthis'] = 'Sync this setting';

$strings['SiteNameExample'] = 'Example: Chamilo';
$strings['InstitutionExample'] = 'Example: Chamilo Association';
$strings['RootWebExample'] = 'Example: http://www.chamilo.org/ (with final slash)';
$strings['DatabaseDescription'] = 'A new database will be created with that name.';
$strings['RootWebExists'] = 'An instance with the same root web exists.';
$strings['ImportInstance'] = 'Import instance';
$strings['ConfigurationPath'] = 'Chamilo configuration path';
$strings['UploadRealRoot'] = 'Upload files';
$strings['DatabaseAccessShouldBeDifferentThanMasterChamilo'] = 'Database server should be different than the Chamilo master';
$strings['UrlAppendExample'] = 'Example: /chamilo_v1 (with first slash)';

$strings['FromVersion'] = 'From version';
$strings['CoursePath'] = 'Path to courses directory';
$strings['HomePath'] = 'Path to home directory';
$strings['UploadPath'] = 'Path to upload directory';

$strings['ArchiveUrl'] = 'Cache URL';
$strings['HomeUrl'] = 'Home URL';
$strings['UploadUrl'] = 'Upload URL';
$strings['CourseUrl'] = 'Course URL';
$strings['ThemeFolder'] = 'Theme folder';
$strings['ThemeFolderExplanation'] = 'Theme folder should be located inside the web/css/themes/ folder';
